@@ -6,18 +6,23 @@ from asf_search.CMR.translate import try_parse_date
 from asf_search.CMR.translate import try_parse_int
 from asf_search.constants import PRODUCT_TYPE
 
+
 class S1BurstProduct(S1Product):
     """
     S1Product Subclass made specifically for Sentinel-1 SLC-BURST products
-    
+
     Key features/properties:
-    - `properties['burst']` contains SLC-BURST Specific fields such as `fullBurstID` and `burstIndex`
+    - `properties['burst']` contains SLC-BURST Specific fields
+        such as `fullBurstID` and `burstIndex`
     - `properties['additionalUrls']` contains BURST-XML url
     - SLC-BURST specific stacking params
 
-    ASF Dataset Documentation Page: https://asf.alaska.edu/datasets/data-sets/derived-data-sets/sentinel-1-bursts/
+    ASF Dataset Documentation Page:
+        https://asf.alaska.edu/datasets/data-sets/derived-data-sets/sentinel-1-bursts/
     """
+
     _base_properties = {
+        **S1Product._base_properties,
         'bytes': {'path': ['AdditionalAttributes', ('Name', 'BYTE_LENGTH'),  'Values', 0]},
         'absoluteBurstID': {'path': ['AdditionalAttributes', ('Name', 'BURST_ID_ABSOLUTE'), 'Values', 0], 'cast': try_parse_int},
         'relativeBurstID': {'path': ['AdditionalAttributes', ('Name', 'BURST_ID_RELATIVE'), 'Values', 0], 'cast': try_parse_int},
@@ -31,61 +36,58 @@ class S1BurstProduct(S1Product):
 
     def __init__(self, args: Dict = {}, session: ASFSession = ASFSession()):
         super().__init__(args, session)
-        self.properties['sceneName'] = self.properties['fileID']
+        self.properties["sceneName"] = self.properties["fileID"]
 
-        # Gathers burst properties into `burst` specific dict 
+        # Gathers burst properties into `burst` specific dict
         # rather than properties dict to limit breaking changes
-        self.properties['burst'] = {
-            'absoluteBurstID': self.properties.pop('absoluteBurstID'),
-            'relativeBurstID': self.properties.pop('relativeBurstID'),
-            'fullBurstID': self.properties.pop('fullBurstID'),
-            'burstIndex': self.properties.pop('burstIndex'),
-            'samplesPerBurst': self.properties.pop('samplesPerBurst'),
-            'subswath': self.properties.pop('subswath'),
-            'azimuthTime': self.properties.pop('azimuthTime'),
-            'azimuthAnxTime': self.properties.pop('azimuthAnxTime')
+        self.properties["burst"] = {
+            "absoluteBurstID": self.properties.pop("absoluteBurstID"),
+            "relativeBurstID": self.properties.pop("relativeBurstID"),
+            "fullBurstID": self.properties.pop("fullBurstID"),
+            "burstIndex": self.properties.pop("burstIndex"),
+            "samplesPerBurst": self.properties.pop("samplesPerBurst"),
+            "subswath": self.properties.pop("subswath"),
+            "azimuthTime": self.properties.pop("azimuthTime"),
+            "azimuthAnxTime": self.properties.pop("azimuthAnxTime"),
         }
 
-        urls = self.umm_get(self.umm, 'RelatedUrls', ('Type', [('USE SERVICE API', 'URL')]), 0)
+        urls = self.umm_get(
+            self.umm, "RelatedUrls", ("Type", [("USE SERVICE API", "URL")]), 0
+        )
         if urls is not None:
-            self.properties['url'] = urls[0]
-            self.properties['fileName'] = self.properties['fileID'] + '.' + urls[0].split('.')[-1]
-            self.properties['additionalUrls'] = [urls[1]] # xml-metadata url
+            self.properties["url"] = urls[0]
+            self.properties["fileName"] = (
+                self.properties["fileID"] + "." + urls[0].split(".")[-1]
+            )
+            self.properties["additionalUrls"] = [urls[1]]  # xml-metadata url
 
     def get_stack_opts(self, opts: ASFSearchOptions = None):
         """
-        Returns the search options asf-search will use internally to build an SLC-BURST baseline stack from
-        
-        :param opts: additional criteria for limiting 
+        Returns the search options asf-search will use internally
+        to build an SLC-BURST baseline stack from
+
+        :param opts: additional criteria for limiting
         :returns ASFSearchOptions used for build Sentinel-1 SLC-BURST Stack
         """
-        stack_opts = (ASFSearchOptions() if opts is None else copy(opts))
-        
+        stack_opts = ASFSearchOptions() if opts is None else copy(opts)
+
         stack_opts.processingLevel = self.get_default_baseline_product_type()
-        stack_opts.fullBurstID = self.properties['burst']['fullBurstID']
-        stack_opts.polarization = [self.properties['polarization']]
+        stack_opts.fullBurstID = self.properties["burst"]["fullBurstID"]
+        stack_opts.polarization = [self.properties["polarization"]]
         return stack_opts
-    
-    @staticmethod
-    def get_property_paths() -> Dict:
-        return {
-            **S1Product.get_property_paths(),
-            **S1BurstProduct._base_properties
-        }
-    
+
     def _get_additional_filenames_and_urls(self, default_filename: str = None):
         # Burst XML filenames are just numbers, this makes it more indentifiable
         if default_filename is None:
-            default_filename = self.properties['fileName']
-        
+            default_filename = self.properties["fileName"]
+
         file_name = f"{'.'.join(default_filename.split('.')[:-1])}.xml"
-        
-        return [(file_name, self.properties['additionalUrls'][0])]
-    
+
+        return [(file_name, self.properties["additionalUrls"][0])]
+
     @staticmethod
     def get_default_baseline_product_type() -> Union[str, None]:
         """
         Returns the product type to search for when building a baseline stack.
         """
         return PRODUCT_TYPE.BURST
-    
\ No newline at end of file
